@@ -4,8 +4,8 @@ use Moo;
 with 'Search::Elasticsearch::Client::2_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
-our $VERSION='5.00';
-use Search::Elasticsearch 5.00 ();
+our $VERSION='6.80';
+use Search::Elasticsearch 6.00 ();
 
 use Search::Elasticsearch::Util qw(parse_params is_compat);
 use namespace::clean;
@@ -89,7 +89,7 @@ Search::Elasticsearch::Client::2_0::Direct - Thin client with full support for E
 
 =head1 VERSION
 
-version 5.01
+version 6.80
 
 =head1 SYNOPSIS
 
@@ -253,7 +253,7 @@ you can do:
 
     $e->search(
         query => {...},
-        filter_paths => [ 'hits.total', 'hits.hits._source' ]
+        filter_path => [ 'hits.total', 'hits.hits._source' ]
     );
 
 =head2 Ignore parameter
@@ -1611,11 +1611,11 @@ See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsea
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
