@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::2_0::Direct::Nodes;
-$Search::Elasticsearch::Client::2_0::Direct::Nodes::VERSION = '5.01';
+$Search::Elasticsearch::Client::2_0::Direct::Nodes::VERSION = '6.80';
 use Moo;
 with 'Search::Elasticsearch::Client::2_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -17,7 +17,7 @@ Search::Elasticsearch::Client::2_0::Direct::Nodes - A client for running node-le
 
 =head1 VERSION
 
-version 5.01
+version 6.80
 
 =head1 DESCRIPTION
 
@@ -152,11 +152,11 @@ for more information.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
